Documentation
¶
Index ¶
Constants ¶
const ( MaxPathsPerClaim = 8 MaxPathLength = 512 )
Variables ¶
var ( ErrInvalidPath = errors.New("invalid claim path") ErrNotFound = errors.New("claim not found") )
Functions ¶
Types ¶
type Memory ¶
type Memory struct {
// contains filtered or unexported fields
}
type NotAllowed ¶
type NotAllowed struct{ Path string }
func (*NotAllowed) Error ¶
func (e *NotAllowed) Error() string
type Store ¶
type Store interface {
Create(owner string, paths []string, local string) (Claim, error)
Release(owner, id string) error
List() []Claim
ListOwner(owner string) []Claim
}
Store contains only claims backed by a live tunnel session. There is no independent lease lifecycle: the tunnel creates the claim and releases it when the connection closes.
type TooManyClaims ¶
type TooManyClaims struct{}
func (*TooManyClaims) Error ¶
func (*TooManyClaims) Error() string
type TooManyOwnerClaims ¶ added in v0.5.0
type TooManyOwnerClaims struct{}
func (*TooManyOwnerClaims) Error ¶ added in v0.5.0
func (*TooManyOwnerClaims) Error() string
Click to show internal directories.
Click to hide internal directories.